searchNodes=[{"doc":"Pockets is a wrapper around Erlang :ets and :dets , built-in options for memory- and disk-based term storage. It offers simple key/value storage using an interface similar to the Map or Keyword modules. This can be a useful persistent cache for many use cases. Note that this package and the libraries that underpin it may have limitations or specific behaviors that may affect its suitability for various use-cases. For example, the limited support for concurrency provided by the :ets(3) module is not yet provided by :dets . See also stash &quot;What is ETS in Elixir?&quot;","ref":"Pockets.html","title":"Pockets","type":"module"},{"doc":"Closes the given table (i.e. the opposite of open/3 ). Only processes that have opened a table are allowed to close it. For :ets in-memory tables, this is the same as destroy/1 . For :dets disk-based tables, this will save any outstanding changes to the file.","ref":"Pockets.html#close/1","title":"Pockets.close/1","type":"function"},{"doc":"Deletes the entry in table for a specific key . Because this returns the table alias, you can pipe multiple operations together. Examples iex&gt; Pockets . new ( :my_cache ) { :ok , :my_cache } iex&gt; Pockets . merge ( :my_cache , %{ a : &quot;apple&quot; , b : &quot;boy&quot; , c : &quot;cat&quot; } ) :my_cache iex&gt; Pockets . to_map ( :my_cache ) %{ a : &quot;apple&quot; , b : &quot;boy&quot; , c : &quot;cat&quot; } iex&gt; Pockets . delete ( :my_cache , :b ) :my_cache iex&gt; Pockets . to_map ( :my_cache ) %{ a : &quot;apple&quot; , c : &quot;cat&quot; }","ref":"Pockets.html#delete/2","title":"Pockets.delete/2","type":"function"},{"doc":"Destroys the given table. For disk-based ( :dets ) tables, this will delete the backing file. For memory-based ( :ets ) tables, this destroys the table and its contents. Examples iex&gt; Pockets . new ( :my_cache , &quot;/tmp/cache.dets&quot; ) { :ok , :my_cache } iex&gt; Pockets . destroy ( :my_cache ) :ok","ref":"Pockets.html#destroy/1","title":"Pockets.destroy/1","type":"function"},{"doc":"Checks if the given table is empty. This will return true if the given table does not exist. Examples iex&gt; { :ok , tid } = Pockets . new ( :my_cache ) { :ok , :my_cache } iex&gt; Pockets . empty? ( tid ) true","ref":"Pockets.html#empty?/1","title":"Pockets.empty?/1","type":"function"},{"doc":"Checks if the table exists in the Pockets registry. Note: this function does not check whether an ETS or DETS table was created outside of Pockets (e.g. via ETS or DETS directly). For those cases, see :ets.whereis/1 or :dets.info/1 .","ref":"Pockets.html#exists?/1","title":"Pockets.exists?/1","type":"function"},{"doc":"Akin to Enum.filter/2 , this function will pare down the contents of the given table preserving only entries for which fun returns a truthy value. Similar to using Enum.filter/2 on maps, the fun receives a tuple representing the key and the value stored at that location. This Updates the Table In Place! This operation updates the table in place, so it has the potential to delete every item in the table. Use it carefully! If a safer alternative is needed, use Pockets.to_stream/1 to manipulate values and feed the results into a new table. Examples iex&gt; Pockets . new ( :ex ) iex&gt; Pockets . merge ( :ex , %{ a : 12 , b : 7 , c : 22 , d : 8 } ) iex&gt; Pockets . filter ( :ex , fn { _ , v } -&gt; v &gt; 10 end ) :ok iex&gt; Pockets . to_map ( :ex ) %{ a : 12 , c : 22 } See Also reject/2","ref":"Pockets.html#filter/2","title":"Pockets.filter/2","type":"function"},{"doc":"Gets the value for a specific key in the table. For tables of type :set , this function behaves like Map.get/3 : the value is returned (if present), otherwise the default is returned. However, for tables of type :bag and :duplicate_bag , this function will always return a list and the default is ignored. This has to do with keyword lists being the underlying data structure powering all of this. The default value will be returned if the table does not exist. Examples iex&gt; Pockets . new ( :t1 , :memory , type : :set ) { :ok , :t1 } iex&gt; Pockets . get ( :t1 , :x , &quot;Default Value&quot; ) &quot;Default Value&quot; iex&gt; Pockets . new ( :t2 , :memory , type : :bag ) { :ok , :t2 } iex&gt; Pockets . get ( :t2 , :x , &quot;Ignored Default Value&quot; ) [ ] # Bag iex&gt; Pockets . new ( :t_bag , :memory , type : :bag ) { :ok , :t_bag } iex&gt; Pockets . put ( :t_bag , :c , &quot;Cream&quot; ) :t_bag iex&gt; Pockets . put ( :t_bag , :c , &quot;Sugar&quot; ) :t_bag iex&gt; Pockets . put ( :t_bag , :c , &quot;Sugar&quot; ) :t_bag iex&gt; Pockets . get ( :t_bag , :c ) [ &quot;Cream&quot; , &quot;Sugar&quot; ] # Duplicate Bag iex&gt; Pockets . new ( :t_dupe_bag , :memory , type : :duplicate_bag ) { :ok , :t_dupe_bag } iex&gt; Pockets . put ( :t_dupe_bag , :c , &quot;Cream&quot; ) :t_bag iex&gt; Pockets . put ( :t_dupe_bag , :c , &quot;Sugar&quot; ) :t_bag iex&gt; Pockets . put ( :t_dupe_bag , :c , &quot;Sugar&quot; ) :t_bag iex&gt; Pockets . get ( :t_bag , :c ) [ &quot;Cream&quot; , &quot;Sugar&quot; , &quot;Sugar&quot; ]","ref":"Pockets.html#get/3","title":"Pockets.get/3","type":"function"},{"doc":"Checks if the table has the given key . false is returned if the table does not exist.","ref":"Pockets.html#has_key?/2","title":"Pockets.has_key?/2","type":"function"},{"doc":"Increments the value at the given key by the given step (default 1). If the table does not exist or the value at the given key is not a number, no action is taken. Examples iex&gt; Pockets . new ( :inc_table ) :inc_table |&gt; Pockets . incr ( :x ) |&gt; Pockets . incr ( :x ) |&gt; Pockets . get ( :x ) 2 Decrement a value: iex&gt; Pockets . new ( :decr_table ) :decr_table |&gt; Pockets . incr ( :x , - 1 , 10 ) |&gt; Pockets . incr ( :x , - 1 ) |&gt; Pockets . get ( :x ) 8","ref":"Pockets.html#incr/4","title":"Pockets.incr/4","type":"function"},{"doc":"Gets info about the given table. An :error tuple is returned if the table does not exist.","ref":"Pockets.html#info/1","title":"Pockets.info/1","type":"function"},{"doc":"Gets info about the given item in the table. The available items depend on the type of table. An error tuple is returned if the table does not exist.","ref":"Pockets.html#info/2","title":"Pockets.info/2","type":"function"},{"doc":"","ref":"Pockets.html#is_alias/1","title":"Pockets.is_alias/1","type":"macro"},{"doc":"Gets a list of keys in the given table. For larger tables, consider keys_stream/1 An error tuple is returned if the table does not exist.","ref":"Pockets.html#keys/1","title":"Pockets.keys/1","type":"function"},{"doc":"Gets a list of keys in the given table as a stream. An error tuple is returned if the table does not exist.","ref":"Pockets.html#keys_stream/1","title":"Pockets.keys_stream/1","type":"function"},{"doc":"This is a powerful function that lets you merge input into an open table. All data in the input will be added to the table: the keys in the input &quot;have precedence&quot; over pre-existing keys in the table. When the input to be merged is... an alias for another table, the contents from that table are added to the given table_alias a map, the contents from the map are added into the given table_alias a list, the contents from the list are added into the given table_alias Examples # Merging a map into a table: iex&gt; Pockets . new ( :my_cache ) { :ok , :my_cache } iex&gt; Pockets . merge ( :my_cache , %{ a : &quot;apple&quot; , b : &quot;boy&quot; , c : &quot;cat&quot; } ) :my_cache iex&gt; Pockets . to_map ( :my_cache ) %{ a : &quot;apple&quot; , b : &quot;boy&quot; , c : &quot;cat&quot; } # Merging two tables: iex&gt; Pockets . new ( :my_first ) { :ok , :my_first } iex&gt; Pockets . merge ( :my_first , %{ a : &quot;apple&quot; , b : &quot;boy&quot; , c : &quot;cat&quot; } ) :my_first iex&gt; Pockets . new ( :my_second ) { :ok , :my_second } iex&gt; Pockets . merge ( :my_second , %{ x : &quot;xray&quot; , y : &quot;yellow&quot; , z : &quot;zebra&quot; } ) :my_second iex&gt; Pockets . merge ( :my_first , :my_second ) :my_first iex&gt; Pockets . to_map ( :my_first ) %{ a : &quot;apple&quot; , b : &quot;boy&quot; , c : &quot;cat&quot; , x : &quot;xray&quot; , y : &quot;yellow&quot; , z : &quot;zebra&quot; }","ref":"Pockets.html#merge/2","title":"Pockets.merge/2","type":"function"},{"doc":"Creates a new table either in memory (default) or on disk. The second argument specifies the storage mechanism for the table, either a path to a file (as a string) for disk-backed tables ( :dets ), or in :memory for memory-backed tables ( :ets ). The available opts are specific to the storage engine being used. In Memory When creating a new memory-based table (i.e. the second argument is :memory or is omitted), the following options are supported: :type One of [:bag, :duplicate_bag, :set] Default: set :access One of :public | :protected | :private . Default: :public :named_table boolean affects how the table is referenced. If false , the table alias will be a reference (not an atom). Default: true :keypos integer indicating the position of the element of each object to be used as key. Default: 1 :read_concurrency boolean. Default: true :write_concurrency boolean. Default: true :decentralized_counters boolean. Default: false :compressed boolean. Default: false The full list of default options for memory-based tables are: [ type : :set , access : :public , named_table : true , keypos : 1 , read_concurrency : true , write_concurrency : true , decentralized_counters : false , compressed : false ] The structure of the options is changed from the original to make them more compatible with Elixir conventions. See the original documentation for specifics about each option. File-based Tables When creating a new disk-based table (i.e. the second argument is a string path to a file), the following options are supported: :type One of [:bag, :duplicate_bag, :set] Default: set :access One of :read | :read_write . Default: :read_write :auto_save integer or :infinity specifying the autosave interval (where :infinity disables the feature). Default: 180000 (3 minutes) :keypos integer indicating the position of the element of each object to be used as key. Default: 1 :file The name of the file to be opened. Defaults to the table name. (Use of this confusing option is not recommended) :max_no_slots The maximum number of slots to be used. Default: 32 M (million?) :min_no_slots Application performance can be enhanced with this flag by specifying the estimated number of different keys to be stored in the table. Default: 256 (minimum) :ram_file boolean. Whether the table is to be kept in RAM. Keeping the table in RAM can sound like an anomaly, but can enhance the performance of applications that open a table, insert a set of objects, and then close the table. When the table is closed, its contents are written to the disk file. Default: false :repair boolean or :force . The flag specifies if the :dets server invokes the automatic file reparation algorithm. Default: true The default options for disk-based tables are: [ type : :set ] Examples iex&gt; Pockets . new ( :ram_cache , :memory ) { :ok , :ram_cache } iex&gt; Pockets . new ( :disk_cache , &quot;/tmp/my.dets&quot; ) { :ok , :disk_cache }","ref":"Pockets.html#new/3","title":"Pockets.new/3","type":"function"},{"doc":"Open a table for use. The behavior and available options of this function vary depending on the storage mechanism of the table (i.e.memory or disk). Memory-based Tables For memory-based tables open/3 is synonymous with new/3 . Disk-based Tables Because a file is involved, the :create? option provides a bit more control over how to handle cases when the file does not exist. Options :create? Indicates whether a new table should be created if the one being requested does not already exist. Default: false If :create? is true and the filepath indicated by the second argument does not exist, open/3 is synonymous with new/3 . Examples iex&gt; Pockets . open ( :my_cache ) { :ok , :my_cache } iex&gt; Pockets . open ( :my_cache , :memory ) { :ok , :my_cache } iex&gt; Pockets . open ( :disk_cache , &quot;/tmp/cache.dets&quot; ) { :ok , :disk_cache } iex&gt; Pockets . open ( :boo , &quot;/tmp/does_not_exist_yet.dets&quot; , create? : true ) { :ok , :boo }","ref":"Pockets.html#open/3","title":"Pockets.open/3","type":"function"},{"doc":"Puts the given value under key in given table. For tables of type :set , this will behave like Map.put/3 . Other table types aren't as straightforward. See the examples under get/3 Examples # Set iex&gt; Pockets . new ( :t_set ) { :ok , :t_set } iex&gt; Pockets . put ( :t_set , :z , &quot;Zulu&quot; ) :t_set iex&gt; Pockets . get ( :t_set , :z ) &quot;Zulu&quot;","ref":"Pockets.html#put/3","title":"Pockets.put/3","type":"function"},{"doc":"Akin to Enum.reject/2 , this function will pare down the contents of the given table deleting entries for which fun returns a truthy value. Similar to using Enum.filter/2 on maps, the fun receives a tuple representing the key and the value stored at that location. This Updates the Table In Place! This operation updates the table in place, so it has the potential to delete every item in the table. Use it carefully! If a safer alternative is needed, use Pockets.to_stream/1 to manipulate values and feed the results into a new table. Examples iex&gt; Pockets . new ( :ex ) iex&gt; Pockets . merge ( :ex , %{ a : 12 , b : 7 , c : 22 , d : 8 } ) iex&gt; Pockets . reject ( :ex , fn { _ , v } -&gt; v &gt; 10 end ) iex&gt; Pockets . to_map ( :ex ) %{ b : 7 , d : 8 } See Also filter/2","ref":"Pockets.html#reject/2","title":"Pockets.reject/2","type":"function"},{"doc":"Both :ets and :dets files can be saved to disk. You can use this function to persist an in-memory :ets file to disk for later use, or you can use it to make a copy of an existing :dets table. The target file must not be in use by another table; if the target file exists this will return an error unless the :overwrite? option is set to true. Options: overwrite? default: false","ref":"Pockets.html#save_as/3","title":"Pockets.save_as/3","type":"function"},{"doc":"Show all registered Pockets tables. Examples iex&gt; Pockets . show_tables ( ) [ % Pockets.Table { alias : :my_cache , library : :ets , tid : :my_cache , type : :set } ]","ref":"Pockets.html#show_tables/1","title":"Pockets.show_tables/1","type":"function"},{"doc":"Returns the size of the given table, measured by the number of entries. Zero is returned if the table does not exist.","ref":"Pockets.html#size/1","title":"Pockets.size/1","type":"function"},{"doc":"Outputs the contents of the given table to a list. If the table does not exist, an empty list is returned. Although this is useful for debugging purposes, for larger data sets consider using to_stream/1 instead.","ref":"Pockets.html#to_list/1","title":"Pockets.to_list/1","type":"function"},{"doc":"Outputs the contents of the table to a map. If the table does not exist, an empty map is returned. Although this is useful for debugging purposes, for larger data sets consider using to_stream/1 instead.","ref":"Pockets.html#to_map/1","title":"Pockets.to_map/1","type":"function"},{"doc":"Outputs the contents of the table to a stream for lazy evaluation. Returns an error tuple if the table does not exist.","ref":"Pockets.html#to_stream/1","title":"Pockets.to_stream/1","type":"function"},{"doc":"Truncates the given table; this removes all entries from the table while leaving its options intact. Examples iex&gt; Pockets . put ( :my_cache , :a , &quot;Apple&quot; ) |&gt; Pockets . put ( :b , &quot;boy&quot; ) |&gt; Pockets . put ( :c , &quot;Charlie&quot; ) :my_cache iex&gt; Pockets . truncate ( :my_cache ) :my_cache iex&gt; Pockets . to_map ( :my_cache ) %{ }","ref":"Pockets.html#truncate/1","title":"Pockets.truncate/1","type":"function"},{"doc":"A table alias is used to refer to a Pockets table: it is usually an atom, but in some cases it may be a reference (e.g. in an :ets table with named_table: false ).","ref":"Pockets.html#t:alias/0","title":"Pockets.alias/0","type":"type"},{"doc":"A struct defining information about an Erlang :dets disk-based table, adapted from :dets.info/1 . This struct is one of the possible values returned from Pockets.info/1 . Note that :dets refers to a table's filename as a path that has been converted to an atom, e.g. :&quot;/tmp/my_table.dets&quot;","ref":"Pockets.DetsInfo.html","title":"Pockets.DetsInfo","type":"module"},{"doc":"","ref":"Pockets.DetsInfo.html#new/1","title":"Pockets.DetsInfo.new/1","type":"function"},{"doc":"","ref":"Pockets.DetsInfo.html#t:t/0","title":"Pockets.DetsInfo.t/0","type":"type"},{"doc":"A struct defining information about an Erlang :ets in-memory table, adapted from :ets.info/1 This struct is one of the possible values returned from Pockets.info/1 .","ref":"Pockets.EtsInfo.html","title":"Pockets.EtsInfo","type":"module"},{"doc":"","ref":"Pockets.EtsInfo.html#new/1","title":"Pockets.EtsInfo.new/1","type":"function"},{"doc":"","ref":"Pockets.EtsInfo.html#t:t/0","title":"Pockets.EtsInfo.t/0","type":"type"},{"doc":"A simple struct that we store for each Pockets table so that we can nicely map what you use to refer to your Pockets table and what the behind-the-scenes library uses to refer to the table. alias : what you (the developer) uses to refer to your Pocket tables. tid : the table identifier: i.e. what the library uses to identify the table. library : denotes either :ets or :dets type : the type of storage. :bag | :duplicate_bag | :set","ref":"Pockets.Table.html","title":"Pockets.Table","type":"module"},{"doc":"","ref":"Pockets.Table.html#t:t/0","title":"Pockets.Table.t/0","type":"type"},{"doc":"Pockets is an Elixir wrapper around Erlang ETS and DETS , Erlang's built-in solutions for memory- and disk-based term storage. Pockets aims to provide a simple and familiar interface for caching and persisting data by implementing many of the functions found in the built-in Map and Keyword modules. A pocket may hold data in memory or on disk. For those needing more power or versatility than what :ets or :dets can offer, Elixir includes :mnesia . Secondly, the docs on erlang.org are a bit rough to look at for Elixir developers, so this package acts as a case study of the differences between the powerful built-in :ets and :dets libraries. In case it was too subtle, &quot;Pockets&quot; is a name that includes &quot;ETS&quot; for mnemonic purposes.","ref":"readme.html","title":"Pockets","type":"extras"},{"doc":"Add pockets to your list of dependencies in mix.exs : def deps do [ { :pockets , &quot;~&gt; 0.1.0&quot; } ] end","ref":"readme.html#installation","title":"Pockets - Installation","type":"extras"},{"doc":"A simple memory-based cache requires no special arguments: iex&gt; Pockets . new ( :my_cache ) { :ok , :my_cache } iex&gt; Pockets . put ( :my_cache , :a , &quot;Apple&quot; ) |&gt; Pockets . put ( :b , &quot;boy&quot; ) |&gt; Pockets . put ( :c , &quot;Charlie&quot; ) :my_cache iex&gt; Pockets . get ( :my_cache , :c ) &quot;Charlie&quot; Using a disk-based cache is appropriate when you need your data to persist. Just supply a file path as the second argument to Pockets.new/3 : iex&gt; Pockets . new ( :on_disk , &quot;/tmp/cache.dets&quot; ) { :ok , :on_disk } You can easily populate your pocket with existing data: iex&gt; Pockets . new ( :on_disk , &quot;/tmp/cache.dets&quot; ) { :ok , :on_disk } iex&gt; Pockets . merge ( :on_disk , %{ x : &quot;xylophone&quot; , y : &quot;yellow&quot; } ) :on_disk You can easily inspect your data, e.g. using Pockets.to_map/1 : iex&gt; Pockets . to_map ( :on_disk ) %{ x : &quot;xylophone&quot; , y : &quot;yellow&quot; } See the Pockets module documentation for more info!","ref":"readme.html#usage","title":"Pockets - Usage","type":"extras"},{"doc":"&quot;pocket&quot; by Hilmi Hidayat from the Noun Project","ref":"readme.html#image-attribution","title":"Pockets - Image Attribution","type":"extras"},{"doc":"The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Adds support for Pockets.filter/2 and Pockets.reject/2 for in-place editing of tables. Bumps hex dependencies to latest versions.","ref":"changelog.html#v1-3-0","title":"Changelog - v1.3.0","type":"extras"},{"doc":"Adds support for Pockets.incr/4 function Updates dependencies to latest available","ref":"changelog.html#v1-2-0","title":"Changelog - v1.2.0","type":"extras"},{"doc":"Adds Pockets.exists?/1 function. Fix for https://github.com/fireproofsocks/pockets/issues/7 : Now returns :error when table does not exist Various documentation cleanups. Downgrades Logger message from warn to debug when a table already exists. Fixes some improper @specs; various dialyzer fixes Defines behavior for various functions when table does not exist Various code linting","ref":"changelog.html#v1-1-0","title":"Changelog - v1.1.0","type":"extras"},{"doc":"Tests! Support for :bag and :duplicate_bag !","ref":"changelog.html#v1-0-0","title":"Changelog - v1.0.0","type":"extras"},{"doc":"Initial release. Basic functionality present, but untested!","ref":"changelog.html#v0-1-0","title":"Changelog - v0.1.0","type":"extras"}]